@@ -5,20 +5,20 @@ use vars qw($VERSION);
 use Module::Pluggable::Object;
 
 # ObQuote:
-# Bob Porter: Looks like you've been missing a lot of work lately. 
-# Peter Gibbons: I wouldn't say I've been missing it, Bob! 
+# Bob Porter: Looks like you've been missing a lot of work lately.
+# Peter Gibbons: I wouldn't say I've been missing it, Bob!
 
 
-$VERSION = '3.6';
+$VERSION = '3.9';
 
 sub import {
     my $class        = shift;
     my %opts         = @_;
 
-    my ($pkg, $file) = caller; 
+    my ($pkg, $file) = caller;
     # the default name for the method is 'plugins'
     my $sub          = $opts{'sub_name'}  || 'plugins';
-    # get our package 
+    # get our package
     my ($package)    = $opts{'package'} || $pkg;
     $opts{filename}  = $file;
     $opts{package}   = $package;
@@ -44,7 +44,7 @@ sub import {
         if (defined $only) {
             $finder->{'only'} = $only;
         };
-        
+
         return $finder->{'only'};
     };
 
@@ -54,14 +54,15 @@ sub import {
         if (defined $except) {
             $finder->{'except'} = $except;
         };
-        
+
         return $finder->{'except'};
     };
 
 
     no strict 'refs';
-    no warnings 'redefine';
-    *{"$package\::$sub"}    = $subroutine;
+    no warnings qw(redefine prototype);
+
+    *{"$package\::$sub"}        = $subroutine;
     *{"$package\::search_path"} = $searchsub;
     *{"$package\::only"}        = $onlysub;
     *{"$package\::except"}      = $exceptsub;
@@ -83,23 +84,23 @@ Simple use Module::Pluggable -
 
     package MyClass;
     use Module::Pluggable;
-    
+
 
 and then later ...
 
     use MyClass;
     my $mc = MyClass->new();
     # returns the names of all plugins installed under MyClass::Plugin::*
-    my @plugins = $mc->plugins(); 
+    my @plugins = $mc->plugins();
 
 =head1 EXAMPLE
 
 Why would you want to do this? Say you have something that wants to pass an
-object to a number of different plugins in turn. For example you may 
+object to a number of different plugins in turn. For example you may
 want to extract meta-data from every email you get sent and do something
-with it. Plugins make sense here because then you can keep adding new 
-meta data parsers and all the logic and docs for each one will be 
-self contained and new handlers are easy to add without changing the 
+with it. Plugins make sense here because then you can keep adding new
+meta data parsers and all the logic and docs for each one will be
+self contained and new handlers are easy to add without changing the
 core code. For that, you might do something like ...
 
     package Email::Examiner;
@@ -124,8 +125,8 @@ core code. For that, you might do something like ...
 .. and all the plugins will get a chance in turn to look at it.
 
 This can be trivally extended so that plugins could save the email
-somewhere and then no other plugin should try and do that. 
-Simply have it so that the C<examine> method returns C<1> if 
+somewhere and then no other plugin should try and do that.
+Simply have it so that the C<examine> method returns C<1> if
 it has saved the email somewhere. You might also wnat to be paranoid
 and check to see if the plugin has an C<examine> method.
 
@@ -140,20 +141,20 @@ And so on. The sky's the limit.
 
 =head1 DESCRIPTION
 
-Provides a simple but, hopefully, extensible way of having 'plugins' for 
+Provides a simple but, hopefully, extensible way of having 'plugins' for
 your module. Obviously this isn't going to be the be all and end all of
 solutions but it works for me.
 
-Essentially all it does is export a method into your namespace that 
-looks through a search path for .pm files and turn those into class names. 
+Essentially all it does is export a method into your namespace that
+looks through a search path for .pm files and turn those into class names.
 
 Optionally it instantiates those classes for you.
 
 =head1 ADVANCED USAGE
 
-    
+
 Alternatively, if you don't want to use 'plugins' as the method ...
-    
+
     package MyClass;
     use Module::Pluggable sub_name => 'foo';
 
@@ -168,7 +169,7 @@ Or if you want to look in another namespace
     package MyClass;
     use Module::Pluggable search_path => ['Acme::MyClass::Plugin', 'MyClass::Extend'];
 
-or directory 
+or directory
 
     use Module::Pluggable search_dirs => ['mylibs/Foo'];
 
@@ -180,9 +181,9 @@ Or if you want to instantiate each plugin rather than just return the name
 
 and then
 
-    # whatever is passed to 'plugins' will be passed 
-    # to 'new' for each plugin 
-    my @plugins = $mc->plugins(@options); 
+    # whatever is passed to 'plugins' will be passed
+    # to 'new' for each plugin
+    my @plugins = $mc->plugins(@options);
 
 
 alternatively you can just require the module without instantiating it
@@ -230,9 +231,9 @@ and then later ...
 =head1 INNER PACKAGES
 
 If you have, for example, a file B<lib/Something/Plugin/Foo.pm> that
-contains package definitions for both C<Something::Plugin::Foo> and 
-C<Something::Plugin::Bar> then as long as you either have either 
-the B<require> or B<instantiate> option set then we'll also find 
+contains package definitions for both C<Something::Plugin::Foo> and
+C<Something::Plugin::Bar> then as long as you either have either
+the B<require> or B<instantiate> option set then we'll also find
 C<Something::Plugin::Bar>. Nifty!
 
 =head1 OPTIONS
@@ -243,22 +244,22 @@ The options can be ...
 
 =head2 sub_name
 
-The name of the subroutine to create in your namespace. 
+The name of the subroutine to create in your namespace.
 
 By default this is 'plugins'
 
 =head2 search_path
 
-An array ref of namespaces to look in. 
+An array ref of namespaces to look in.
 
-=head2 search_dirs 
+=head2 search_dirs
 
 An array ref of directorys to look in before @INC.
 
 =head2 instantiate
 
 Call this method on the class. In general this will probably be 'new'
-but it can be whatever you want. Whatever arguments are passed to 'plugins' 
+but it can be whatever you want. Whatever arguments are passed to 'plugins'
 will be passed to the method.
 
 The default is 'undef' i.e just return the class name.
@@ -269,18 +270,18 @@ Just require the class, don't instantiate (overrides 'instantiate');
 
 =head2 inner
 
-If set to 0 will B<not> search inner packages. 
+If set to 0 will B<not> search inner packages.
 If set to 1 will override C<require>.
 
 =head2 only
 
-Takes a string, array ref or regex describing the names of the only plugins to 
-return. Whilst this may seem perverse ... well, it is. But it also 
+Takes a string, array ref or regex describing the names of the only plugins to
+return. Whilst this may seem perverse ... well, it is. But it also
 makes sense. Trust me.
 
 =head2 except
 
-Similar to C<only> it takes a description of plugins to exclude 
+Similar to C<only> it takes a description of plugins to exclude
 from returning. This is slightly less perverse.
 
 =head2 package
@@ -297,14 +298,22 @@ By supplying a new C<file_regex> then you can change this behaviour e.g
 
     file_regex => qr/\.plugin$/
 
+=head2 include_editor_junk
+
+By default C<Module::Pluggable> ignores files that look like they were
+left behind by editors. Currently this means files ending in F<~> (~),
+the extensions F<.swp> or F<.swo>, or files beginning with F<.#>.
+
+Setting C<include_editor_junk> changes C<Module::Pluggable> so it does
+not ignore any files it finds.
 
 
 =head1 METHODs
 
 =head2 search_path
 
-The method C<search_path> is exported into you namespace as well. 
-You can call that at any time to change or replace the 
+The method C<search_path> is exported into you namespace as well.
+You can call that at any time to change or replace the
 search_path.
 
     $self->search_path( add => "New::Path" ); # add
@@ -314,10 +323,10 @@ search_path.
 
 =head1 FUTURE PLANS
 
-This does everything I need and I can't really think of any other 
+This does everything I need and I can't really think of any other
 features I want to add. Famous last words of course
 
-Recently tried fixed to find inner packages and to make it 
+Recently tried fixed to find inner packages and to make it
 'just work' with PAR but there are still some issues.
 
 
@@ -341,6 +350,6 @@ None known.
 
 L<File::Spec>, L<File::Find>, L<File::Basename>, L<Class::Factory::Util>, L<Module::Pluggable::Ordered>
 
-=cut 
+=cut
 
 
